@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_EXCEPTIONHANDLER_H
 #define _GLIBMM_EXCEPTIONHANDLER_H
 
-/* $Id: exceptionhandler.h,v 1.1.1.1 2003/01/07 16:58:46 murrayc Exp $ */
+/* $Id: exceptionhandler.h,v 1.2 2004/02/10 14:26:04 murrayc Exp $ */
 
 /* exceptionhandler.h
  *
@@ -31,7 +31,7 @@ namespace Glib
 
 /** Specify a slot to be called when an exception is thrown by a signal handler.
  */
-SigC::Connection add_exception_handler(const SigC::Slot0<void>& slot);
+sigc::connection add_exception_handler(const sigc::slot<void>& slot);
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 // internal
