@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: miscutils.cc,v 1.3 2005/01/09 18:04:53 murrayc Exp $ */
+/* $Id: miscutils.cc,v 1.3.2.1 2005/06/07 06:34:35 gustin Exp $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -100,7 +100,8 @@ std::string get_real_name()
 
 std::string get_home_dir()
 {
-  return std::string(g_get_home_dir());
+  const char *const value = g_get_home_dir();
+  return (value) ? std::string(value) : std::string();
 }
 
 std::string get_tmp_dir()
